<?php

// Tłumaczenie na języki polski
// Translation to Polish
//
// Tomek 'TomasH' Zielinski
// tomash@fidonet.org.pl, tomash@4net.pl

$loginbox_text = array (
'username'	=>	'Nazwa użytkownika',
'password'	=>	'Hasło',
'login'		=>	'Zaloguj!',

// Added in 0.9.6
'rememberme'	=>	'Zapamiętaj dane', 

// Added in 0.9.7
'lostpassword'				=>	'Zapomniane hasło?',

);
// vim:fenc=utf-8:enc=utf-8
?>
